Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispatcher(String key, dynamic value, {String? scope})
→ void
-
emit a new event
-
emit(String key, dynamic value, {String? scope})
→ void
-
emit a new event - alias of dispatcher
-
hasState(String key)
→ bool
-
-
initAction()
→ FutureOr<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifier<T extends ValueNotifier>(String key)
→ T
-
-
notifierOrNull<T extends ValueNotifier>(String key)
→ T?
-
-
on<T>(String key, void handler(T? value), {String? scope})
→ StreamSubscription<T?>
-
-
once<T>(String key, void handler(T? value), {String? scope})
→ void
-
-
receiver<T>(String key, {T? initalValue, String? scope})
→ Stream<T?>
-
Listen events, but can receive null
-
receiverNotNull<T>(String key, T initalValue, {String? scope})
→ Stream<T>
-
Listen events
-
registerNotifier(String key, {StreamController? controler, String? scope, bool override = false})
→ void
-
Declare a new a stream events
-
removeState(String key)
→ dynamic
-
-
state<T extends ValueNotifier>(String key, [dynamic value])
→ T
-
-
stateOrNull<T extends ValueNotifier>(String key, [dynamic value])
→ T?
-
-
toString()
→ String
-
A string representation of this object.
inherited